import React, { useState, useEffect } from "react";
import { Button, Modal, Input, Icon } from "semantic-ui-react";

import "./ModalProduct.css";

const ModalProduct = props => {
  const [productName, setProductName] = useState("");
  const [productPrice, setProductPrice] = useState("");
  const [productTags, setProductTags] = useState([]);
  const [priceError, setPriceError] = useState(false);

  useEffect(() => {
    if (props.item.name) {
      setProductName(props.item.name);
      setProductPrice(props.item.price.toString());
    } else {
      resetState();
    }
  }, [props.item]);
  const handleConfirm = () => {
    let price = parseFloat(productPrice.replace(",", "."));
    if (isNaN(price)) {
      setPriceError(true);
    } else {
      price = Math.round(price * 100) / 100;
      props.onConfirm(
        { name: productName, price, tags: productTags },
        props.edit_mode
      );
      // resetState();
    }
  };

  const resetState = () => {
    setProductName("");
    setProductPrice("");
    setProductTags([]);
    setPriceError(false);
  };

  const onNameChange = event => {
    setProductName(event.target.value);
  };

  const onPriceChange = event => {
    setProductPrice(event.target.value);
  };

  return (
    <Modal size="mini" open={props.open} onClose={props.onClose}>
      <Modal.Content>
        <p>{props.edit_mode ? "Edytuj" : "Dodaj nowy"} produkt</p>
        <Input
          value={productName}
          onChange={onNameChange}
          icon="write"
          iconPosition="left"
          placeholder="Nazwa produktu"
        />
        <Input
          value={productPrice}
          onChange={onPriceChange}
          icon="money"
          error={priceError && true}
          iconPosition="left"
          placeholder="0,00"
        />
        <Input
          action={{ icon: "add" }}
          icon="tags"
          iconPosition="left"
          placeholder="Dodaj tag"
        />
      </Modal.Content>
      <Modal.Actions>
        {props.edit_mode && (
          <Icon
            name="trash alternate"
            size="large"
            color="red"
            onClick={props.onRemove}
          />
        )}
        {productName !== "" && productPrice !== "" && (
          <Button
            positive
            icon="checkmark"
            labelPosition="right"
            content="Zapisz"
            onClick={() => {
              handleConfirm();
            }}
          />
        )}
        <Button
          negative
          icon="cancel"
          labelPosition="right"
          content="Anuluj"
          onClick={() => {
            props.onClose();
            // resetState();
          }}
        />
      </Modal.Actions>
    </Modal>
  );
};

export default ModalProduct;
