import React, { useRef, useState, useEffect } from "react";
import {
  Button,
  Container,
  Image,
  Icon,
  Menu,
  Search,
  Input,
  Dimmer,
  Loader
} from "semantic-ui-react";
// import { DateInput } from "semantic-ui-calendar-react";
import SemanticDatepicker from "react-semantic-ui-datepickers";
import { useHistory } from "react-router-dom";
import axios, { post } from "axios";

import useGlobal from "../../../../utils/global_state";
import config from "../../../../config";
import "./AddMetadata.css";

function AddMetadata() {
  const history = useHistory();
  const fileInputRef = useRef(null);
  const [selectedFile, setSelectedFile] = useState(null);
  const [pickedDate, setPickedDate] = useState("");
  const [shops, setShops] = useState([]);
  const [shopsLoading, setShopsLoading] = useState(true);
  const [globalState, globalActions] = useGlobal();
  const [pickedShop, changePickedShop] = useState("");
  const [photoIsLoading, setPhotoIsLoading] = useState(false);
  const [productsFromPhoto, setProductsFromPhoto] = useState(null);

  const uploadPhoto = event => {
    setPhotoIsLoading(true);
    // setSelectedFile(URL.createObjectURL(event.target.files[0]));
    fileUploadRequest(event.target.files[0], true)
      .then(resp => {
        const reader = new FileReader();
        reader.addEventListener("loadend", e => {
          const text = e.srcElement.result;
          setProductsFromPhoto(JSON.parse(text).products);
        });
        reader.readAsText(resp.data);
      })
      .catch(error => {
        console.log(error);
      });

    fileUploadRequest(event.target.files[0])
      .then(resp => {
        setSelectedFile(URL.createObjectURL(resp.data));
        setPhotoIsLoading(false);
      })
      .catch(error => {
        console.log(error);
        setPhotoIsLoading(false);
      });
  };

  const get_mata_data_obj = () => {
    const products = productsFromPhoto ? productsFromPhoto : [];
    products.forEach(product => {
      product.price = parseFloat(product.price.replace(",", "."));
    });
    console.log(products);
    const date = pickedDate.toISOString().slice(0, 10);
    return {
      shop: pickedShop,
      date,
      products
    };
  };

  const fileUploadRequest = (file, get_products = false) => {
    let url = `${config.api_url}/api/photo/`;
    if (!get_products) {
      url += "debug_img/";
    }

    const formData = new FormData();
    formData.append("image", file);
    const cnf = {
      headers: {
        "content-type": "multipart/form-data",
        Authorization: `Token ${globalState.auth_token}`
      },
      responseType: "blob"
    };
    return post(url, formData, cnf);
  };

  //set date to current day
  useEffect(() => {
    let todayDate = new Date();
    setPickedDate(todayDate);
  }, []);

  //fetch shops data
  useEffect(() => {
    setShopsLoading(true);
    axios
      .get(`${config.api_url}/api/shops/`, {
        headers: { Authorization: `Token ${globalState.auth_token}` }
      })
      .then(resp => {
        setTimeout(() => {
          setShops(resp.data);
          setShopsLoading(false);
        }, 1000);
      })
      .catch(err => {
        console.log(err);
        setShopsLoading(false);
      });
  }, []);

  const handleDateChange = (event, data) => {
    setPickedDate(data.value);
  };

  const handleShopChange = event => {
    changePickedShop(event.target.value);
  };
  return (
    <div className="site-wrapper">
      <Menu icon className="nav-menu">
        <Menu.Item onClick={() => history.push("/home")}>
          <Icon name="arrow left" />
        </Menu.Item>
      </Menu>
      <div className="add_metadata">
        {shopsLoading && (
          <Dimmer active>
            <Loader size="massive">Loading</Loader>
          </Dimmer>
        )}
        <Container>
          <SemanticDatepicker
            onChange={handleDateChange}
            placeholder="Data zakupu"
            filterDate={date => {
              return new Date() > date;
            }}
            value={pickedDate}
          />
          <Input
            onChange={handleShopChange}
            fluid
            list="shops"
            placeholder="Wybierz sklep..."
          />
          <datalist id="shops">
            {shops.map((shop, index) => (
              <option key={index} value={shop.name} />
            ))}
          </datalist>
        </Container>
        <input
          type="file"
          hidden
          id="mypic"
          accept="image/*"
          ref={fileInputRef}
          onChange={uploadPhoto}
        />
        <Button
          fluid
          icon
          color="orange"
          onClick={() => fileInputRef.current.click()}
          className="add-product-btn"
        >
          <Icon name="camera" />
          Dodaj zdjęcie
        </Button>

        <Button
          fluid
          icon
          disabled={pickedDate === "" || pickedShop === ""}
          color="olive"
          onClick={() => {
            history.push("/home/add_receipt/list", get_mata_data_obj());
          }}
          className="add-product-btn"
        >
          <Icon name="arrow right" />
          Dalej
        </Button>

        {productsFromPhoto && (
          <Container>Rozpoznane produkty: {productsFromPhoto.length}</Container>
        )}

        {selectedFile && <Image centered src={selectedFile} size="medium" />}
        {photoIsLoading && (
          <Dimmer active>
            <Loader size="massive">Loading</Loader>
          </Dimmer>
        )}
      </div>
    </div>
  );
}

export default AddMetadata;
