import React, { useState, useEffect } from "react";
import { Button, Container, Icon, Menu } from "semantic-ui-react";
import { useHistory } from "react-router-dom";

import axios from "axios";

import { fake_product } from "../../../../utils/gen_fake_data";
import config from "../../../../config";
import useGlobal from "../../../../utils/global_state";
import { ProductTile, ModalConfirm, ModalProduct } from "../../components";
import "./ProductsList.css";

function ProductsList() {
  const [products, setProducts] = useState([]);
  const [confirmModalOpen, setConfirmModalOpen] = useState(false);
  const [productModalOpen, setProductModalOpen] = useState(false);
  const [globalState, globalActions] = useGlobal();

  // none, edit, add
  const [productModalMode, setProductModalMode] = useState("none");
  const [pickedProduct, setPickedProduct] = useState(-1);
  const history = useHistory();

  useEffect(() => {
    const meta_products = history.location.state.products;
    console.log(meta_products);
    if (meta_products) {
      const new_products = [];
      for (let i = 0; i < meta_products.length; i++) {
        new_products.push({
          name: meta_products[i].name,
          price: meta_products[i].price,
          tags: []
        });
      }
      console.log(new_products);
      setProducts(new_products);
    }
  }, []);
  const meta_info = history.location.state;
  const addItem = item => {
    setProducts([...products, item]);
  };

  const updateItem = (item, index) => {
    console.log(`Update item ${index} to ${item.name} ${item.price}`);
    products[index] = item;
  };

  const removeItem = index => {
    const new_products = [...products];
    new_products.splice(index, 1);
    setProducts([...new_products]);
  };

  const openProductModal = (mode, picked_index = -1) => {
    setPickedProduct(picked_index);
    setProductModalMode(mode);
    setProductModalOpen(true);
  };

  const closeProductModal = () => {
    setProductModalMode("none");
    setProductModalOpen(false);
  };

  const handleConfirmProduct = (item, is_in_edit_mode) => {
    if (is_in_edit_mode) {
      updateItem(item, pickedProduct);
    } else {
      console.log("add new product!", item);
      addItem(item);
    }
    setProductModalOpen(false);
  };

  const openConfirmModal = () => {
    setConfirmModalOpen(true);
  };
  const closeConfirmModal = () => {
    setConfirmModalOpen(false);
  };

  const handleConfirm = () => {
    const new_receipt = {
      date: meta_info.date,
      shop: { name: meta_info.shop, tags: [] },
      products
    };
    console.log(new_receipt);
    axios
      .post(`${config.api_url}/api/receipts/`, new_receipt, {
        headers: { Authorization: `Token ${globalState.auth_token}` }
      })
      .then(resp => {
        console.log(resp);
        history.push("/home");
      })
      .catch(err => {
        console.log(err);
      });
  };

  return (
    <div className="site-wrapper">
      <Menu icon className="nav-menu">
        <Menu.Item onClick={() => history.push("/home")}>
          <Icon name="arrow left" />
        </Menu.Item>
      </Menu>
      <div className="add_receipt-container">
        <Container className="products-list-container">
          {products.map((product, index) => (
            <ProductTile
              text="keh"
              key={index}
              number={index + 1}
              name={product.name}
              price={product.price}
              onClick={() => {
                openProductModal("edit", index);
              }}
              onRemove={() => {
                removeItem(index);
              }}
            />
          ))}
        </Container>
        <Container textAlign="right">
          Razem: {products.length > 0 ? sum_products_prices(products) : "-"}
          zł
        </Container>
        <Button
          fluid
          icon
          color="green"
          onClick={() => {
            // addItem(fake_product());
            openProductModal("add", -1);
          }}
          className="add-product-btn"
        >
          <Icon name="plus" />
          Dodaj produkt
        </Button>
        {products.length > 0 && (
          <Button
            fluid
            icon
            color="olive"
            onClick={openConfirmModal}
            className="add-product-btn"
          >
            <Icon name="upload" />
            Dodaj paragon
          </Button>
        )}
      </div>
      <ModalConfirm
        open={confirmModalOpen}
        onClose={closeConfirmModal}
        onConfirm={handleConfirm}
      />

      <ModalProduct
        open={productModalOpen}
        onClose={closeProductModal}
        onConfirm={handleConfirmProduct}
        edit_mode={productModalMode === "edit"}
        item={pickedProduct === -1 ? {} : products[pickedProduct]}
        onRemove={() => {
          setPickedProduct(-1);
          closeProductModal();
          removeItem(pickedProduct);
        }}
      />
    </div>
  );
}

function sum_products_prices(products) {
  let sum = 0;
  products.forEach(prod => (sum += prod.price));
  sum.toFixed(2);
  return sum;
}

export default ProductsList;
