import React, { useState } from "react";
import {
  Sidebar,
  Container,
  Icon,
  Menu,
  Accordion,
  Segment,
  Table
} from "semantic-ui-react";
import {
  Link,
  Switch,
  Route,
  useHistory,
  useRouteMatch
} from "react-router-dom";

import { Receipts, Shops, Products, Tags } from "./subscreens";
import "./Digest.css";

function Digest() {
  const history = useHistory();
  const match = useRouteMatch();
  const [visible, setVisible] = useState(false);

  const handleSidebarItemClick = () => {
    setVisible(false);
  };

  return (
    <Sidebar.Pushable>
      <Sidebar
        as={Menu}
        animation="overlay"
        icon="labeled"
        inverted
        onHide={() => setVisible(false)}
        vertical
        visible={visible}
        width="thin"
      >
        <Menu.Item onClick={handleSidebarItemClick}>
          <Link to={`${match.url}/receipts`}> Paragony </Link>
        </Menu.Item>
        <Menu.Item onClick={handleSidebarItemClick}>
          <Link to={`${match.url}/shops`}> Sklepy </Link>
        </Menu.Item>
        <Menu.Item onClick={handleSidebarItemClick}>
          <Link to={`${match.url}/products`}> Produkty </Link>
        </Menu.Item>
        <Menu.Item onClick={handleSidebarItemClick}>
          <Link to={`${match.url}/tags`}> Tagi </Link>
        </Menu.Item>
      </Sidebar>

      <Sidebar.Pusher dimmed={visible}>
        <Menu icon>
          <Menu.Item onClick={() => history.push("/home")}>
            <Icon name="arrow left" />
          </Menu.Item>
          <Menu.Item position="right" onClick={() => setVisible(true)}>
            <Icon name="sidebar" />
          </Menu.Item>
        </Menu>
        <Container>
          <Switch>
            <Route path={`${match.path}/receipts`}>
              <Receipts />
            </Route>
            <Route path={`${match.path}/shops`}>
              <Shops />
            </Route>
            <Route path={`${match.path}/products`}>
              <Products />
            </Route>
            <Route path={`${match.path}/tags`}>
              <Tags />
            </Route>
          </Switch>
        </Container>
      </Sidebar.Pusher>
    </Sidebar.Pushable>
  );
}

export default Digest;
