import React, { useState, useEffect } from "react";
import {
  Dimmer,
  Loader,
  Container,
  Menu,
  Accordion,
  Table,
  Pagination
} from "semantic-ui-react";
import axios from "axios";

import useGlobal from "../../../../utils/global_state";
import config from "../../../../config";

function ReceiptEntery(props) {
  return (
    <div>
      <Accordion.Title
        index={props.index}
        active={props.activeIndex === props.index}
        onClick={() => props.handleClick(props.activeIndex, props.index)}
      >
        {`${props.date} | ${props.shop.name} | ${props.price}zł`}
      </Accordion.Title>
      <Accordion.Content active={props.activeIndex === props.index}>
        <Table celled unstackable>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell>Produkt</Table.HeaderCell>
              <Table.HeaderCell>Cena</Table.HeaderCell>
            </Table.Row>
            {props.products.map((item, index) => (
              <Table.Row key={index}>
                <Table.Cell>{item.name}</Table.Cell>
                <Table.Cell>{item.price}zł</Table.Cell>
              </Table.Row>
            ))}
          </Table.Header>
        </Table>
      </Accordion.Content>
    </div>
  );
}

function Receipts() {
  const [receipts, setReceipts] = useState([]);
  const [receiptsLoading, setReceiptsLoading] = useState(false);
  const [page, setPage] = useState(1);
  const [activeIndex, setActiveIndex] = useState(-1);
  const [globalState, globalActions] = useGlobal();
  const [maxPage, setMaxPage] = useState(1);
  const [currentPage, setCurrentPage] = useState(1);

  const handleClick = (oldIndex, index) => {
    const newIndex = oldIndex === index ? -1 : index;
    setActiveIndex(newIndex);
  };

  // load data on first render
  useEffect(() => {
    setReceiptsLoading(true);
    axios
      .get(`${config.api_url}/api/receipts/?page=${currentPage}`, {
        headers: { Authorization: `Token ${globalState.auth_token}` }
      })
      .then(resp => {
        processResponse(resp.data);
      })
      .catch(err => {
        console.log(err);
        setReceiptsLoading(false);
      });
  }, [currentPage]);

  const handlePageChange = (event, paginator_data) => {
    console.log(paginator_data.activePage);
    setCurrentPage(paginator_data.activePage);
  };

  const processResponse = data => {
    setReceipts(data.results);
    setReceiptsLoading(false);
    setMaxPage(Math.ceil(data.count / 10));
  };

  return (
    <Container textAlign="center">
      {receiptsLoading && (
        <Dimmer active>
          <Loader size="massive">Loading</Loader>
        </Dimmer>
      )}
      {maxPage !== 1 && (
        <Pagination
          boundaryRange={0}
          defaultActivePage={1}
          ellipsisItem={null}
          // firstItem={null}
          // lastItem={null}
          siblingRange={1}
          totalPages={maxPage}
          onPageChange={handlePageChange}
        />
      )}
      <Accordion fluid styled>
        {receipts.map((item, index) => (
          <ReceiptEntery
            activeIndex={activeIndex}
            handleClick={handleClick}
            index={index}
            key={index}
            date={item.date}
            price={item.total_price}
            products={item.products}
            shop={item.shop}
          />
        ))}
      </Accordion>
    </Container>
  );
}

export default Receipts;
