import React, { useState, useEffect } from "react";
import {
  Button,
  Form,
  Grid,
  Segment,
  Container,
  Image,
  Message
} from "semantic-ui-react";
import { useHistory } from "react-router-dom";

import useGlobal from "../../utils/global_state";
import logo from "../../img/logo_project.svg";
import "./Login.css";

function Login() {
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const history = useHistory();
  const [globalState, globalActions] = useGlobal();

  const handleSubmit = () => {
    globalActions.login({ username, password });
  };

  useEffect(() => {
    if (globalState.is_authenticated) {
      history.push("/home");
    }
  });

  return (
    <Container className="login-container">
      <Grid columns={1} verticalAlign="middle" style={{ height: "100%" }}>
        <Grid.Column>
          <Image src={logo} size="medium" centered />
          <Segment>
            <Form size="large">
              <Form.Input
                fluid
                icon="user"
                iconPosition="left"
                placeholder="Nazwa użytkownika"
                onChange={e => {
                  setUsername(e.target.value);
                }}
              />
              <Form.Input
                fluid
                icon="lock"
                iconPosition="left"
                placeholder="Hasło"
                type="password"
                onChange={e => {
                  setPassword(e.target.value);
                }}
              />
              <Button
                basic
                fluid
                color="yellow"
                size="large"
                onClick={() => handleSubmit()}
              >
                Login
              </Button>
            </Form>
          </Segment>
          {globalState.auth_error != "" && (
            <Message>
              <p>Błąd: {globalState.auth_error}</p>
            </Message>
          )}
        </Grid.Column>
      </Grid>
    </Container>
  );
}

export default Login;
