import React, { useState } from "react";
import { Container, Icon, Menu, Sidebar } from "semantic-ui-react";
import {
  Link,
  Switch,
  Route,
  useHistory,
  useRouteMatch
} from "react-router-dom";

import "./Statistics.css";
import { Shops, Products, Summary } from "./subscreens";

function Statistics() {
  const history = useHistory();
  const match = useRouteMatch();
  const [visible, setVisible] = useState(false);
  const handleSidebarItemClick = (event, data) => {
    history.push(`${match.path}/${data.target}`);
    setVisible(false);
  };

  return (
    <Sidebar.Pushable>
      <Sidebar
        as={Menu}
        animation="overlay"
        icon="labeled"
        inverted
        onHide={() => setVisible(false)}
        vertical
        visible={visible}
        width="thin"
      >
        <Menu.Item target="summary" onClick={handleSidebarItemClick}>
          Ogólne
        </Menu.Item>
        <Menu.Item target="products" onClick={handleSidebarItemClick}>
          Produkty
        </Menu.Item>
        <Menu.Item target="shops" onClick={handleSidebarItemClick}>
          Sklepy
        </Menu.Item>
      </Sidebar>

      <Sidebar.Pusher dimmed={visible}>
        <Menu icon>
          <Menu.Item onClick={() => history.push("/home")}>
            <Icon name="arrow left" />
          </Menu.Item>

          <Menu.Item position="right" onClick={() => setVisible(true)}>
            <Icon name="sidebar" />
          </Menu.Item>
        </Menu>
        <Container>
          <Switch>
            <Route path={`${match.path}/summary`}>
              <Summary />
            </Route>
            <Route path={`${match.path}/shops`}>
              <Shops />
            </Route>
            <Route path={`${match.path}/products`}>
              <Products />
            </Route>
          </Switch>
        </Container>
      </Sidebar.Pusher>
    </Sidebar.Pushable>
  );
}

export default Statistics;
