import React from "react";
import globalHook from "use-global-hook";
import axios from "axios";
import config from "../config";

const initialState = {
  auth_token: "",
  auth_error: "",
  is_authenticated: false
};

const getInitialState = () => {
  const auth_token = localStorage.getItem("user_auth_token");
  const is_authenticated = auth_token ? true : false;
  return { ...initialState, auth_token, is_authenticated };
};

const actions = {
  login: (store, { username, password }) => {
    console.log("Try to login...");
    axios
      .post(`${config.api_url}/api/auth/login/`, {
        username: username,
        password: password
      })
      .then(resp => {
        localStorage.setItem("user_auth_token", resp.data.token);
        const newToken = resp.data.token;
        store.setState({
          auth_token: newToken,
          is_authenticated: true,
          auth_error: ""
        });
      })
      .catch(err => {
        console.log(err);
        store.setState({
          auth_error: "Podany login i/lub hasło są nieprawidłowe.",
          is_authenticated: false
        });
      });
  },
  logout: store => {
    axios
      .post(
        `${config.api_url}/api/auth/logout/`,
        {},
        {
          headers: { Authorization: `Token ${store.state.auth_token}` }
        }
      )
      .then(resp => {
        localStorage.clear();
        store.setState(getInitialState());
      })
      .catch(err => {
        console.log(err);
        localStorage.clear();
        store.setState({
          auth_error: "Nastąpił błąd przy wylogowywaniu",
          is_authenticated: false,
          auth_token: ""
        });
      });
  }
};

const useGlobal = globalHook(React, getInitialState(), actions);
export default useGlobal;
